@@ -4,13 +4,22 @@
 # Licensed under the terms of the MIT License
 # (see LICENSE.txt for details)
 # -----------------------------------------------------------------------------
+
 """Provides QtTextToSpeech classes and functions."""
 
-from . import PYQT5, PYSIDE2, PythonQtError
+from . import (
+    PYQT5,
+    PYQT6,
+    PYSIDE2,
+    PYSIDE6,
+    QtBindingMissingModuleError,
+)
 
 if PYQT5:
     from PyQt5.QtTextToSpeech import *
+elif PYQT6:
+    raise QtBindingMissingModuleError(name='QtTextToSpeech')
 elif PYSIDE2:
     from PySide2.QtTextToSpeech import *
-else:
-    raise PythonQtError('No Qt bindings could be found')
+elif PYSIDE6:
+    raise QtBindingMissingModuleError(name='QtTextToSpeech')
