@@ -1,12 +1,12 @@
-from __future__ import absolute_import
-
 import pytest
-from qtpy import PYSIDE2, PYSIDE
+from qtpy import PYSIDE2
 
-@pytest.mark.skipif(PYSIDE2 or PYSIDE, reason="QtDesigner is not avalaible in PySide/PySide2")
+
+@pytest.mark.skipif(PYSIDE2, reason="QtDesigner is not available in PySide2")
 def test_qtdesigner():
-    from qtpy import QtDesigner
-    """Test the qtpy.QtDesigner namespace"""
+    """Test the qtpy.QtDesigner namespace."""
+    QtDesigner = pytest.importorskip("qtpy.QtDesigner")
+
     assert QtDesigner.QAbstractExtensionFactory is not None
     assert QtDesigner.QAbstractExtensionManager is not None
     assert QtDesigner.QDesignerActionEditorInterface is not None
@@ -25,4 +25,4 @@ def test_qtdesigner():
     assert QtDesigner.QDesignerWidgetBoxInterface is not None
     assert QtDesigner.QExtensionFactory is not None
     assert QtDesigner.QExtensionManager is not None
-    assert QtDesigner.QFormBuilder is not None
\ No newline at end of file
+    assert QtDesigner.QFormBuilder is not None
